.. Buckaroo documentation master file, created by
   sphinx-quickstart on Wed Apr 19 14:07:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Buckaroo - The Data Cleaning assistant for pandas
=================================================
Buckaroo is a tool to quickly clean and explore DataFrames with a visual UI for common cleaning operations AND emitting python code that performs the transformation. 


We all know how awkward it is to clean data in jupyter notebooks.  Multiple cells of exploratory work, trying different transforms, looking up different transforms, adhoc functions that work in one notebook and have to be either copied/pasta-ed to the next notebook, or rewritten from scratch.  Buckaroo aims to massively speed up that process.

.. raw:: html

	 <iframe width="560" height="315" src="https://www.youtube.com/embed/3XdU5hpOUYY" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>


.. toctree::
   :maxdepth: 2
   :caption: Sitemap:

   using
   feature_reference
   install
   contributing
   FAQ
   articles/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

* `Buckaroo on github <https://github.com/paddymul/buckaroo>`_
